==> libreoffice-fresh-sdk-7.6.0-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_6.js <==
var searchData=
[
  ['galleryitem_2eidl_0',['GalleryItem.idl',['../GalleryItem_8idl.html',1,'']]],
  ['galleryitemtype_2eidl_1',['GalleryItemType.idl',['../GalleryItemType_8idl.html',1,'']]],
  ['gallerytheme_2eidl_2',['GalleryTheme.idl',['../GalleryTheme_8idl.html',1,'']]],
  ['gallerythemeprovider_2eidl_3',['GalleryThemeProvider.idl',['../GalleryThemeProvider_8idl.html',1,'']]],
  ['generalfunction_2eidl_4',['GeneralFunction.idl',['../GeneralFunction_8idl.html',1,'']]],
  ['generalfunction2_2eidl_5',['GeneralFunction2.idl',['../GeneralFunction2_8idl.html',1,'']]],
  ['generated_5fidl_5fchapter_5frefs_2eidl_6',['generated_idl_chapter_refs.idl',['../generated__idl__chapter__refs_8idl.html',1,'']]],
  ['genericclipboard_2eidl_7',['GenericClipboard.idl',['../GenericClipboard_8idl.html',1,'']]],
  ['genericdrawingdocument_2eidl_8',['GenericDrawingDocument.idl',['../GenericDrawingDocument_8idl.html',1,'']]],
  ['genericdrawpage_2eidl_9',['GenericDrawPage.idl',['../GenericDrawPage_8idl.html',1,'']]],
  ['genericpropertyhandler_2eidl_10',['GenericPropertyHandler.idl',['../GenericPropertyHandler_8idl.html',1,'']]],
  ['generictextdocument_2eidl_11',['GenericTextDocument.idl',['../GenericTextDocument_8idl.html',1,'']]],
  ['getdirectpropertytolerantresult_2eidl_12',['GetDirectPropertyTolerantResult.idl',['../GetDirectPropertyTolerantResult_8idl.html',1,'']]],
  ['getexpression_2eidl_13',['GetExpression.idl',['../GetExpression_8idl.html',1,'']]],
  ['getpropertytolerantresult_2eidl_14',['GetPropertyTolerantResult.idl',['../GetPropertyTolerantResult_8idl.html',1,'']]],
  ['getreference_2eidl_15',['GetReference.idl',['../GetReference_8idl.html',1,'']]],
  ['giocontentprovider_2eidl_16',['GIOContentProvider.idl',['../GIOContentProvider_8idl.html',1,'']]],
  ['globalacceleratorconfiguration_2eidl_17',['GlobalAcceleratorConfiguration.idl',['../GlobalAcceleratorConfiguration_8idl.html',1,'']]],
  ['globaldocument_2eidl_18',['GlobalDocument.idl',['../GlobalDocument_8idl.html',1,'']]],
  ['globaleventbroadcaster_2eidl_19',['GlobalEventBroadcaster.idl',['../GlobalEventBroadcaster_8idl.html',1,'']]],
  ['globalsettings_2eidl_20',['GlobalSettings.idl',['../GlobalSettings_8idl.html',1,'']]],
  ['globalsheetsettings_2eidl_21',['GlobalSheetSettings.idl',['../GlobalSheetSettings_8idl.html',1,'']]],
  ['globaltransfercommandargument_2eidl_22',['GlobalTransferCommandArgument.idl',['../GlobalTransferCommandArgument_8idl.html',1,'']]],
  ['globaltransfercommandargument2_2eidl_23',['GlobalTransferCommandArgument2.idl',['../GlobalTransferCommandArgument2_8idl.html',1,'']]],
  ['gluepoint_2eidl_24',['GluePoint.idl',['../GluePoint_8idl.html',1,'']]],
  ['gluepoint2_2eidl_25',['GluePoint2.idl',['../GluePoint2_8idl.html',1,'']]],
  ['gnomevfscontentprovider_2eidl_26',['GnomeVFSContentProvider.idl',['../GnomeVFSContentProvider_8idl.html',1,'']]],
  ['gnomevfsdocumentcontent_2eidl_27',['GnomeVFSDocumentContent.idl',['../GnomeVFSDocumentContent_8idl.html',1,'']]],
  ['gnomevfsfoldercontent_2eidl_28',['GnomeVFSFolderContent.idl',['../GnomeVFSFolderContent_8idl.html',1,'']]],
  ['goalresult_2eidl_29',['GoalResult.idl',['../GoalResult_8idl.html',1,'']]],
  ['gpgseinitializer_2eidl_30',['GPGSEInitializer.idl',['../GPGSEInitializer_8idl.html',1,'']]],
  ['gradient_2eidl_31',['Gradient.idl',['../Gradient_8idl.html',1,'']]],
  ['gradient2_2eidl_32',['Gradient2.idl',['../Gradient2_8idl.html',1,'']]],
  ['gradientstyle_2eidl_33',['GradientStyle.idl',['../GradientStyle_8idl.html',1,'']]],
  ['gradienttable_2eidl_34',['GradientTable.idl',['../GradientTable_8idl.html',1,'']]],
  ['graphic_2eidl_35',['Graphic.idl',['../Graphic_8idl.html',1,'']]],
  ['graphiccolormode_2eidl_36',['GraphicColorMode.idl',['../GraphicColorMode_8idl.html',1,'']]],
  ['graphiccrop_2eidl_37',['GraphicCrop.idl',['../GraphicCrop_8idl.html',1,'']]],
  ['graphicdescriptor_2eidl_38',['GraphicDescriptor.idl',['../GraphicDescriptor_8idl.html',1,'']]],
  ['graphicexportfilter_2eidl_39',['GraphicExportFilter.idl',['../GraphicExportFilter_8idl.html',1,'']]],
  ['graphicfilterrequest_2eidl_40',['GraphicFilterRequest.idl',['../GraphicFilterRequest_8idl.html',1,'']]],
  ['graphiclocation_2eidl_41',['GraphicLocation.idl',['../GraphicLocation_8idl.html',1,'']]],
  ['graphicmapper_2eidl_42',['GraphicMapper.idl',['../GraphicMapper_8idl.html',1,'']]],
  ['graphicobject_2eidl_43',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
  ['graphicobjectcount_2eidl_44',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
  ['graphicobjectshape_2eidl_45',['GraphicObjectShape.idl',['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
  ['graphicprovider_2eidl_46',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
  ['graphicrasterizer_2eidl_47',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
  ['graphicrenderervcl_2eidl_48',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
  ['graphicstoragehandler_2eidl_49',['GraphicStorageHandler.idl',['../GraphicStorageHandler_8idl.html',1,'']]],
  ['graphictype_2eidl_50',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
  ['gridcolumn_2eidl_51',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
  ['gridcolumnevent_2eidl_52',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
  ['gridcontrol_2eidl_53',['GridControl.idl',['../control_2GridControl_8idl.html',1,'(Global Namespace)'],['../component_2GridControl_8idl.html',1,'(Global Namespace)']]],
  ['griddataevent_2eidl_54',['GridDataEvent.idl',['../GridDataEvent_8idl.html',1,'']]],
  ['gridinvaliddataexception_2eidl_55',['GridInvalidDataException.idl',['../GridInvalidDataException_8idl.html',1,'']]],
  ['gridinvalidmodelexception_2eidl_56',['GridInvalidModelException.idl',['../GridInvalidModelException_8idl.html',1,'']]],
  ['gridproperties_2eidl_57',['GridProperties.idl',['../GridProperties_8idl.html',1,'']]],
  ['gridselectionevent_2eidl_58',['GridSelectionEvent.idl',['../GridSelectionEvent_8idl.html',1,'']]],
  ['group_2eidl_59',['Group.idl',['../sdbcx_2Group_8idl.html',1,'(Global Namespace)'],['../report_2Group_8idl.html',1,'(Global Namespace)']]],
  ['groupaccess_2eidl_60',['GroupAccess.idl',['../GroupAccess_8idl.html',1,'']]],
  ['groupbox_2eidl_61',['GroupBox.idl',['../component_2GroupBox_8idl.html',1,'(Global Namespace)'],['../control_2GroupBox_8idl.html',1,'(Global Namespace)']]],
  ['groupdescriptor_2eidl_62',['GroupDescriptor.idl',['../GroupDescriptor_8idl.html',1,'']]],
  ['groupelement_2eidl_63',['GroupElement.idl',['../GroupElement_8idl.html',1,'']]],
  ['groupkeeptogether_2eidl_64',['GroupKeepTogether.idl',['../GroupKeepTogether_8idl.html',1,'']]],
  ['groupon_2eidl_65',['GroupOn.idl',['../GroupOn_8idl.html',1,'']]],
  ['groups_2eidl_66',['Groups.idl',['../Groups_8idl.html',1,'']]],
  ['groupshape_2eidl_67',['GroupShape.idl',['../GroupShape_8idl.html',1,'']]],
  ['groupupdate_2eidl_68',['GroupUpdate.idl',['../GroupUpdate_8idl.html',1,'']]]
];

==> libreoffice-fresh-sdk-7.6.4-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_6.js <==
var searchData=
[
  ['galleryitem_2eidl_0',['GalleryItem.idl',['../GalleryItem_8idl.html',1,'']]],
  ['galleryitemtype_2eidl_1',['GalleryItemType.idl',['../GalleryItemType_8idl.html',1,'']]],
  ['gallerytheme_2eidl_2',['GalleryTheme.idl',['../GalleryTheme_8idl.html',1,'']]],
  ['gallerythemeprovider_2eidl_3',['GalleryThemeProvider.idl',['../GalleryThemeProvider_8idl.html',1,'']]],
  ['generalfunction_2eidl_4',['GeneralFunction.idl',['../GeneralFunction_8idl.html',1,'']]],
  ['generalfunction2_2eidl_5',['GeneralFunction2.idl',['../GeneralFunction2_8idl.html',1,'']]],
  ['generated_5fidl_5fchapter_5frefs_2eidl_6',['generated_idl_chapter_refs.idl',['../generated__idl__chapter__refs_8idl.html',1,'']]],
  ['genericclipboard_2eidl_7',['GenericClipboard.idl',['../GenericClipboard_8idl.html',1,'']]],
  ['genericdrawingdocument_2eidl_8',['GenericDrawingDocument.idl',['../GenericDrawingDocument_8idl.html',1,'']]],
  ['genericdrawpage_2eidl_9',['GenericDrawPage.idl',['../GenericDrawPage_8idl.html',1,'']]],
  ['genericpropertyhandler_2eidl_10',['GenericPropertyHandler.idl',['../GenericPropertyHandler_8idl.html',1,'']]],
  ['generictextdocument_2eidl_11',['GenericTextDocument.idl',['../GenericTextDocument_8idl.html',1,'']]],
  ['getdirectpropertytolerantresult_2eidl_12',['GetDirectPropertyTolerantResult.idl',['../GetDirectPropertyTolerantResult_8idl.html',1,'']]],
  ['getexpression_2eidl_13',['GetExpression.idl',['../GetExpression_8idl.html',1,'']]],
  ['getpropertytolerantresult_2eidl_14',['GetPropertyTolerantResult.idl',['../GetPropertyTolerantResult_8idl.html',1,'']]],
  ['getreference_2eidl_15',['GetReference.idl',['../GetReference_8idl.html',1,'']]],
  ['giocontentprovider_2eidl_16',['GIOContentProvider.idl',['../GIOContentProvider_8idl.html',1,'']]],
  ['globalacceleratorconfiguration_2eidl_17',['GlobalAcceleratorConfiguration.idl',['../GlobalAcceleratorConfiguration_8idl.html',1,'']]],
  ['globaldocument_2eidl_18',['GlobalDocument.idl',['../GlobalDocument_8idl.html',1,'']]],
  ['globaleventbroadcaster_2eidl_19',['GlobalEventBroadcaster.idl',['../GlobalEventBroadcaster_8idl.html',1,'']]],
  ['globalsettings_2eidl_20',['GlobalSettings.idl',['../GlobalSettings_8idl.html',1,'']]],
  ['globalsheetsettings_2eidl_21',['GlobalSheetSettings.idl',['../GlobalSheetSettings_8idl.html',1,'']]],
  ['globaltransfercommandargument_2eidl_22',['GlobalTransferCommandArgument.idl',['../GlobalTransferCommandArgument_8idl.html',1,'']]],
  ['globaltransfercommandargument2_2eidl_23',['GlobalTransferCommandArgument2.idl',['../GlobalTransferCommandArgument2_8idl.html',1,'']]],
  ['gluepoint_2eidl_24',['GluePoint.idl',['../GluePoint_8idl.html',1,'']]],
  ['gluepoint2_2eidl_25',['GluePoint2.idl',['../GluePoint2_8idl.html',1,'']]],
  ['gnomevfscontentprovider_2eidl_26',['GnomeVFSContentProvider.idl',['../GnomeVFSContentProvider_8idl.html',1,'']]],
  ['gnomevfsdocumentcontent_2eidl_27',['GnomeVFSDocumentContent.idl',['../GnomeVFSDocumentContent_8idl.html',1,'']]],
  ['gnomevfsfoldercontent_2eidl_28',['GnomeVFSFolderContent.idl',['../GnomeVFSFolderContent_8idl.html',1,'']]],
  ['goalresult_2eidl_29',['GoalResult.idl',['../GoalResult_8idl.html',1,'']]],
  ['gpgseinitializer_2eidl_30',['GPGSEInitializer.idl',['../GPGSEInitializer_8idl.html',1,'']]],
  ['gradient_2eidl_31',['Gradient.idl',['../Gradient_8idl.html',1,'']]],
  ['gradient2_2eidl_32',['Gradient2.idl',['../Gradient2_8idl.html',1,'']]],
  ['gradientstyle_2eidl_33',['GradientStyle.idl',['../GradientStyle_8idl.html',1,'']]],
  ['gradienttable_2eidl_34',['GradientTable.idl',['../GradientTable_8idl.html',1,'']]],
  ['graphic_2eidl_35',['Graphic.idl',['../Graphic_8idl.html',1,'']]],
  ['graphiccolormode_2eidl_36',['GraphicColorMode.idl',['../GraphicColorMode_8idl.html',1,'']]],
  ['graphiccrop_2eidl_37',['GraphicCrop.idl',['../GraphicCrop_8idl.html',1,'']]],
  ['graphicdescriptor_2eidl_38',['GraphicDescriptor.idl',['../GraphicDescriptor_8idl.html',1,'']]],
  ['graphicexportfilter_2eidl_39',['GraphicExportFilter.idl',['../GraphicExportFilter_8idl.html',1,'']]],
  ['graphicfilterrequest_2eidl_40',['GraphicFilterRequest.idl',['../GraphicFilterRequest_8idl.html',1,'']]],
  ['graphiclocation_2eidl_41',['GraphicLocation.idl',['../GraphicLocation_8idl.html',1,'']]],
  ['graphicmapper_2eidl_42',['GraphicMapper.idl',['../GraphicMapper_8idl.html',1,'']]],
  ['graphicobject_2eidl_43',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
  ['graphicobjectcount_2eidl_44',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
  ['graphicobjectshape_2eidl_45',['graphicobjectshape.idl',['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
  ['graphicprovider_2eidl_46',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
  ['graphicrasterizer_2eidl_47',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
  ['graphicrenderervcl_2eidl_48',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
  ['graphicstoragehandler_2eidl_49',['GraphicStorageHandler.idl',['../GraphicStorageHandler_8idl.html',1,'']]],
  ['graphictype_2eidl_50',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
  ['gridcolumn_2eidl_51',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
  ['gridcolumnevent_2eidl_52',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
  ['gridcontrol_2eidl_53',['gridcontrol.idl',['../control_2GridControl_8idl.html',1,'(Global Namespace)'],['../component_2GridControl_8idl.html',1,'(Global Namespace)']]],
  ['griddataevent_2eidl_54',['GridDataEvent.idl',['../GridDataEvent_8idl.html',1,'']]],
  ['gridinvaliddataexception_2eidl_55',['GridInvalidDataException.idl',['../GridInvalidDataException_8idl.html',1,'']]],
  ['gridinvalidmodelexception_2eidl_56',['GridInvalidModelException.idl',['../GridInvalidModelException_8idl.html',1,'']]],
  ['gridproperties_2eidl_57',['GridProperties.idl',['../GridProperties_8idl.html',1,'']]],
  ['gridselectionevent_2eidl_58',['GridSelectionEvent.idl',['../GridSelectionEvent_8idl.html',1,'']]],
  ['group_2eidl_59',['group.idl',['../sdbcx_2Group_8idl.html',1,'(Global Namespace)'],['../report_2Group_8idl.html',1,'(Global Namespace)']]],
  ['groupaccess_2eidl_60',['GroupAccess.idl',['../GroupAccess_8idl.html',1,'']]],
  ['groupbox_2eidl_61',['groupbox.idl',['../component_2GroupBox_8idl.html',1,'(Global Namespace)'],['../control_2GroupBox_8idl.html',1,'(Global Namespace)']]],
  ['groupdescriptor_2eidl_62',['GroupDescriptor.idl',['../GroupDescriptor_8idl.html',1,'']]],
  ['groupelement_2eidl_63',['GroupElement.idl',['../GroupElement_8idl.html',1,'']]],
  ['groupkeeptogether_2eidl_64',['GroupKeepTogether.idl',['../GroupKeepTogether_8idl.html',1,'']]],
  ['groupon_2eidl_65',['GroupOn.idl',['../GroupOn_8idl.html',1,'']]],
  ['groups_2eidl_66',['Groups.idl',['../Groups_8idl.html',1,'']]],
  ['groupshape_2eidl_67',['GroupShape.idl',['../GroupShape_8idl.html',1,'']]],
  ['groupupdate_2eidl_68',['GroupUpdate.idl',['../GroupUpdate_8idl.html',1,'']]]
];
